@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2024 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2025 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -21,8 +21,7 @@
 #ifndef ROCRAND_DISCRETE_H_
 #define ROCRAND_DISCRETE_H_
 
-#include <math.h>
-
+#include "rocrand/rocrand_common.h"
 #include "rocrand/rocrand_lfsr113.h"
 #include "rocrand/rocrand_mrg31k3p.h"
 #include "rocrand/rocrand_mrg32k3a.h"
@@ -38,7 +37,9 @@
 #include "rocrand/rocrand_threefry4x64_20.h"
 #include "rocrand/rocrand_xorwow.h"
 
-#include "rocrand/rocrand_discrete_types.h"
+#include <hip/hip_runtime.h>
+
+#include <math.h>
 
 // On certain architectures such as NAVI2 and NAVI3, double arithmetic is significantly slower.
 // In such cases we want to prefer the CDF method over the alias method.
@@ -179,14 +180,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using Philox generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_philox4x32_10*        state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_philox4x32_10*        state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_alias(rocrand(state), *discrete_distribution);
 }
@@ -198,13 +199,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using Philox generator in \p state, and increments
  * the position of the generator by four.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return Four <tt>unsigned int</tt> values distributed according to \p discrete_distribution as \p uint4
  */
-__forceinline__ __device__ __host__ uint4 rocrand_discrete4(
-    rocrand_state_philox4x32_10* state, const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+uint4 rocrand_discrete4(rocrand_state_philox4x32_10*        state,
+                        const rocrand_discrete_distribution discrete_distribution)
 {
     const uint4 u4 = rocrand4(state);
     return uint4 {
@@ -222,14 +224,14 @@ __forceinline__ __device__ __host__ uint4 rocrand_discrete4(
  * \p discrete_distribution using MRG31k3p generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_mrg31k3p*             state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_mrg31k3p*             state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_alias(rocrand(state), *discrete_distribution);
 }
@@ -241,14 +243,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using MRG32k3a generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_mrg32k3a*             state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_mrg32k3a*             state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_alias(rocrand(state), *discrete_distribution);
 }
@@ -260,14 +262,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using XORWOW generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_xorwow*               state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_xorwow*               state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_alias(rocrand(state), *discrete_distribution);
 }
@@ -279,14 +281,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using MTGP32 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ unsigned int
-    rocrand_discrete(rocrand_state_mtgp32*               state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__
+unsigned int rocrand_discrete(rocrand_state_mtgp32*               state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
@@ -302,14 +304,14 @@ __forceinline__ __device__ unsigned int
  * \p discrete_distribution using SOBOL32 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_sobol32*              state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_sobol32*              state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
 }
@@ -321,14 +323,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using SCRAMBLED_SOBOL32 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_scrambled_sobol32*    state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_scrambled_sobol32*    state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
 }
@@ -340,14 +342,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using SOBOL64 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned long long int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_sobol64*              state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_sobol64*              state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
 }
@@ -359,14 +361,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using SCRAMBLED_SOBOL64 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned long long int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_scrambled_sobol64*    state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_scrambled_sobol64*    state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
 }
@@ -378,14 +380,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using LFSR113 generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_lfsr113*              state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_lfsr113*              state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
@@ -401,14 +403,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using ThreeFry generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_threefry2x32_20*      state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_threefry2x32_20*      state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
@@ -424,14 +426,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using ThreeFry generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_threefry2x64_20*      state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_threefry2x64_20*      state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
@@ -447,14 +449,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using ThreeFry generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_threefry4x32_20*      state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_threefry4x32_20*      state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
@@ -470,14 +472,14 @@ __forceinline__ __device__ __host__ unsigned int
  * \p discrete_distribution using ThreeFry generator in \p state, and increments
  * the position of the generator by one.
  *
- * \param state - Pointer to a state to use
- * \param discrete_distribution - Related discrete distribution
+ * \param state Pointer to a state to use
+ * \param discrete_distribution Related discrete distribution
  *
  * \return <tt>unsigned int</tt> value distributed according to \p discrete_distribution
  */
-__forceinline__ __device__ __host__ unsigned int
-    rocrand_discrete(rocrand_state_threefry4x64_20*      state,
-                     const rocrand_discrete_distribution discrete_distribution)
+__forceinline__ __device__ __host__
+unsigned int rocrand_discrete(rocrand_state_threefry4x64_20*      state,
+                              const rocrand_discrete_distribution discrete_distribution)
 {
 #ifdef ROCRAND_PREFER_CDF_OVER_ALIAS
     return rocrand_device::detail::discrete_cdf(rocrand(state), *discrete_distribution);
