@@ -1,4 +1,4 @@
-// Copyright (c) 2022-2024 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2022-2025 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -50,26 +50,29 @@ THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef ROCRAND_THREEFRY2X32_20_H_
-#define ROCRAND_THREEFRY2X32_20_H_
+#ifndef ROCRAND_THREEFRY2X64_20_H_
+#define ROCRAND_THREEFRY2X64_20_H_
 
 #include "rocrand/rocrand_threefry2_impl.h"
 
+#include <hip/hip_runtime.h>
+
 namespace rocrand_device
 {
 
-class threefry2x32_20_engine : public threefry_engine2_base<uint2, unsigned int, 20>
+class threefry2x64_20_engine : public threefry_engine2_base<ulonglong2, unsigned long long, 20>
 {
 public:
-    ROCRAND_DEPRECATED("Alias \"threefry2x32_20_state\" is deprecated. Use \"state_type\" instead.")
-    typedef threefry_engine2_base<uint2, unsigned int, 20>::threefry_state_2 threefry2x32_20_state;
+    ROCRAND_DEPRECATED("Alias \"threefry2x64_20_state\" is deprecated. Use \"state_type\" instead.")
+    typedef threefry_engine2_base<ulonglong2, unsigned long long, 20>::threefry_state_2
+        threefry2x64_20_state;
 
     /// Initializes the internal state of the PRNG using
     /// seed value \p seed, goes to \p subsequence -th subsequence,
     /// and skips \p offset random numbers.
     ///
-    /// A subsequence consists of 2 ^ 33 random numbers.
-    __forceinline__ __device__ __host__ threefry2x32_20_engine(const unsigned long long seed = 0,
+    /// A subsequence consists of 2 ^ 65 random numbers.
+    __forceinline__ __device__ __host__ threefry2x64_20_engine(const unsigned long long seed = 0,
                                                                const unsigned long long subsequence
                                                                = 0,
                                                                const unsigned long long offset = 0)
@@ -81,27 +84,26 @@ public:
     /// seed value \p seed_value, skips \p subsequence subsequences
     /// and \p offset random numbers.
     ///
-    /// A subsequence consists of 2 ^ 33 random numbers.
+    /// A subsequence consists of 2 ^ 65 random numbers.
     __forceinline__ __device__ __host__ void seed(const unsigned long long seed        = 0,
                                                   const unsigned long long subsequence = 0,
                                                   const unsigned long long offset      = 0)
     {
-        m_state.counter  = {0U, 0U};
-        m_state.result   = {0U, 0U};
+        m_state.counter  = {0ULL, 0ULL};
+        m_state.key      = {seed, seed >> 32};
+        m_state.result   = {0ULL, 0ULL};
         m_state.substate = 0;
 
-        m_state.key = {static_cast<unsigned int>(seed), static_cast<unsigned int>(seed >> 32)};
-
         this->discard_subsequence_impl(subsequence);
         this->discard(offset);
         m_state.result = this->threefry_rounds(m_state.counter, m_state.key);
     }
 
-}; // threefry2x32_20_engine class
+}; // threefry2x64_20_engine class
 
 } // end namespace rocrand_device
 
-typedef rocrand_device::threefry2x32_20_engine rocrand_state_threefry2x32_20;
+typedef rocrand_device::threefry2x64_20_engine rocrand_state_threefry2x64_20;
 
 /**
  * \brief Initializes Threefry state.
@@ -109,53 +111,56 @@ typedef rocrand_device::threefry2x32_20_engine rocrand_state_threefry2x32_20;
  * Initializes the Threefry generator \p state with the given
  * \p seed, \p subsequence, and \p offset.
  *
- * \param seed - Value to use as a seed
- * \param subsequence - Subsequence to start at
- * \param offset - Absolute offset into subsequence
- * \param state - Pointer to state to initialize
+ * \param seed Value to use as a seed
+ * \param subsequence Subsequence to start at
+ * \param offset Absolute offset into subsequence
+ * \param state Pointer to state to initialize
  */
-__forceinline__ __device__ __host__ void rocrand_init(const unsigned long long       seed,
-                                                      const unsigned long long       subsequence,
-                                                      const unsigned long long       offset,
-                                                      rocrand_state_threefry2x32_20* state)
+__forceinline__ __device__ __host__
+void rocrand_init(const unsigned long long       seed,
+                  const unsigned long long       subsequence,
+                  const unsigned long long       offset,
+                  rocrand_state_threefry2x64_20* state)
 {
-    *state = rocrand_state_threefry2x32_20(seed, subsequence, offset);
+    *state = rocrand_state_threefry2x64_20(seed, subsequence, offset);
 }
 
 /**
- * \brief Returns uniformly distributed random <tt>unsigned int</tt> value
- * from [0; 2^32 - 1] range.
+ * \brief Returns uniformly distributed random <tt>unsigned long long</tt> value
+ * from [0; 2^64 - 1] range.
  *
- * Generates and returns uniformly distributed random <tt>unsigned int</tt>
- * value from [0; 2^32 - 1] range using Threefry generator in \p state.
+ * Generates and returns uniformly distributed random <tt>unsigned long long</tt>
+ * value from [0; 2^64 - 1] range using Threefry generator in \p state.
  * State is incremented by one position.
  *
- * Threefry2x32 has a period of 2 ^ 64 numbers.
+ * Threefry2x64 has a period of 2 ^ 128 numbers.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
- * \return Pseudorandom value (32-bit) as an <tt>unsigned int</tt>
+ * \return Pseudorandom value (64-bit) as an <tt>unsigned long long</tt>
  */
-__forceinline__ __device__ __host__ unsigned int rocrand(rocrand_state_threefry2x32_20* state)
+__forceinline__ __device__ __host__
+unsigned long long rocrand(rocrand_state_threefry2x64_20* state)
 {
     return state->next();
 }
 
 /**
- * \brief Returns two uniformly distributed random <tt>unsigned int</tt> values
- * from [0; 2^32 - 1] range.
+ * \brief Returns two uniformly distributed random <tt>unsigned long long</tt> values
+ * from [0; 2^64 - 1] range.
  *
- * Generates and returns two uniformly distributed random <tt>unsigned int</tt>
- * values from [0; 2^32 - 1] range using Threefry generator in \p state.
+ * Generates and returns two uniformly distributed random <tt>unsigned long long</tt>
+ * values from [0; 2^64 - 1] range using Threefry generator in \p state.
  * State is incremented by two positions.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
- * \return Two pseudorandom values (32-bit) as an <tt>uint2</tt>
+ * \return Two pseudorandom values (64-bit) as an <tt>ulonglong2</tt>
  */
-__forceinline__ __device__ __host__ uint2 rocrand2(rocrand_state_threefry2x32_20* state)
+__forceinline__ __device__ __host__
+ulonglong2 rocrand2(rocrand_state_threefry2x64_20* state)
 {
     return state->next2();
 }
 
-#endif // ROCRAND_THREEFRY2X32_20_H_
+#endif // ROCRAND_THREEFRY2X64_20_H_
