@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2021 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2024 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -43,24 +43,22 @@ TEST_P(rocrand_generate_tests, int_test)
 
     const size_t size = 12563;
     unsigned int * data;
-    HIP_CHECK(hipMallocHelper(reinterpret_cast<void**>(&data), size * sizeof(unsigned int)));
+    HIP_CHECK(hipMallocHelper(&data, size * sizeof(unsigned int)));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any sizes
-    ROCRAND_CHECK(
-        rocrand_generate(generator, data, 1)
-    );
+    ROCRAND_CHECK(rocrand_generate(generator, data, 1));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any alignment
-    ROCRAND_CHECK(
-        rocrand_generate(generator, data+1, 2)
-    );
+    ROCRAND_CHECK(rocrand_generate(generator, data + 1, 2));
     HIP_CHECK(hipDeviceSynchronize());
 
-    ROCRAND_CHECK(
-        rocrand_generate(generator, data, size)
-    );
+    ROCRAND_CHECK(rocrand_generate(generator, data, size));
+    HIP_CHECK(hipDeviceSynchronize());
+
+    // No output pointer
+    ROCRAND_CHECK(rocrand_generate(generator, nullptr, size));
     HIP_CHECK(hipDeviceSynchronize());
 
     HIP_CHECK(hipFree(data));
@@ -81,24 +79,22 @@ TEST_P(rocrand_generate_tests, char_test)
 
     const size_t size = 12563;
     unsigned char * data;
-    HIP_CHECK(hipMallocHelper(reinterpret_cast<void**>(&data), size * sizeof(unsigned char)));
+    HIP_CHECK(hipMallocHelper(&data, size * sizeof(unsigned char)));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any sizes
-    ROCRAND_CHECK(
-        rocrand_generate_char(generator, data, 1)
-    );
+    ROCRAND_CHECK(rocrand_generate_char(generator, data, 1));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any alignment
-    ROCRAND_CHECK(
-        rocrand_generate_char(generator, data+1, 2)
-    );
+    ROCRAND_CHECK(rocrand_generate_char(generator, data + 1, 2));
     HIP_CHECK(hipDeviceSynchronize());
 
-    ROCRAND_CHECK(
-        rocrand_generate_char(generator, data, size)
-    );
+    ROCRAND_CHECK(rocrand_generate_char(generator, data, size));
+    HIP_CHECK(hipDeviceSynchronize());
+
+    // No output pointer
+    ROCRAND_CHECK(rocrand_generate_char(generator, nullptr, size));
     HIP_CHECK(hipDeviceSynchronize());
 
     HIP_CHECK(hipFree(data));
@@ -119,24 +115,22 @@ TEST_P(rocrand_generate_tests, short_test)
 
     const size_t size = 12563;
     unsigned short * data;
-    HIP_CHECK(hipMallocHelper(reinterpret_cast<void**>(&data), size * sizeof(unsigned short)));
+    HIP_CHECK(hipMallocHelper(&data, size * sizeof(unsigned short)));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any sizes
-    ROCRAND_CHECK(
-        rocrand_generate_short(generator, data, 1)
-    );
+    ROCRAND_CHECK(rocrand_generate_short(generator, data, 1));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any alignment
-    ROCRAND_CHECK(
-        rocrand_generate_short(generator, data+1, 2)
-    );
+    ROCRAND_CHECK(rocrand_generate_short(generator, data + 1, 2));
     HIP_CHECK(hipDeviceSynchronize());
 
-    ROCRAND_CHECK(
-        rocrand_generate_short(generator, data, size)
-    );
+    ROCRAND_CHECK(rocrand_generate_short(generator, data, size));
+    HIP_CHECK(hipDeviceSynchronize());
+
+    // No output pointer
+    ROCRAND_CHECK(rocrand_generate_short(generator, nullptr, size));
     HIP_CHECK(hipDeviceSynchronize());
 
     HIP_CHECK(hipFree(data));
@@ -146,13 +140,21 @@ TEST_P(rocrand_generate_tests, short_test)
 TEST(rocrand_generate_tests, neg_test)
 {
     const size_t size = 256;
-    unsigned int * data = NULL;
+    void*        data = nullptr;
 
-    rocrand_generator generator = NULL;
-    EXPECT_EQ(
-        rocrand_generate(generator, (unsigned int *) data, size),
-        ROCRAND_STATUS_NOT_CREATED
-    );
+    rocrand_generator generator = nullptr;
+
+    EXPECT_EQ(rocrand_generate(generator, static_cast<unsigned int*>(data), size),
+              ROCRAND_STATUS_NOT_CREATED);
+
+    EXPECT_EQ(rocrand_generate_char(generator, static_cast<unsigned char*>(data), size),
+              ROCRAND_STATUS_NOT_CREATED);
+
+    EXPECT_EQ(rocrand_generate_short(generator, static_cast<unsigned short*>(data), size),
+              ROCRAND_STATUS_NOT_CREATED);
+
+    EXPECT_EQ(rocrand_generate_long_long(generator, static_cast<unsigned long long*>(data), size),
+              ROCRAND_STATUS_NOT_CREATED);
 }
 
 INSTANTIATE_TEST_SUITE_P(rocrand_generate_tests,
@@ -171,8 +173,7 @@ TEST_P(rocrand_generate_long_long_tests, long_long_test)
 
     const size_t            size = 12563;
     unsigned long long int* data;
-    HIP_CHECK(
-        hipMallocHelper(reinterpret_cast<void**>(&data), size * sizeof(unsigned long long int)));
+    HIP_CHECK(hipMallocHelper(&data, size * sizeof(unsigned long long int)));
     HIP_CHECK(hipDeviceSynchronize());
 
     // Any sizes
@@ -186,6 +187,10 @@ TEST_P(rocrand_generate_long_long_tests, long_long_test)
     ROCRAND_CHECK(rocrand_generate_long_long(generator, data, size));
     HIP_CHECK(hipDeviceSynchronize());
 
+    // No output pointer
+    ROCRAND_CHECK(rocrand_generate_long_long(generator, nullptr, size));
+    HIP_CHECK(hipDeviceSynchronize());
+
     HIP_CHECK(hipFree(data));
     ROCRAND_CHECK(rocrand_destroy_generator(generator));
 }
